// adc.c
/*----------------------------------------------------------------------*/
/*! \file 
--------------------------------------------------------------------------

  	<h3> adc.C </h3>
  	Version	1.0<br>
  	Revision	$Revision: 1.4 $<br>
 	Copyright 	Thomas Wedemeyer, Email: avr@thomas-wedemeyer.de<br> 
  	Datum		$Date<br>

	<h1>ADC-Functions for IO-Interface for the Linksys WRT54 
	with Atmel AVR ATMega8</h1>  

/*----------------------------------------------------------------------*/


#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/signal.h>
#include <stdlib.h>
#include <stdio.h>
#include <inttypes.h>
#include <stdint.h> 
#include "pin.h"
#include "adc.h"


/*----------------------------------------------------------------------*/
//!	Init of the adc-hardware
//! @brief 10Bit  115KHz ADCClk at 7.372MHz
/*----------------------------------------------------------------------*/
void init_adc()
{
	
	ADMUX = (1<<REFS0);	// REFS = 0,1 -> Reference = VCC plus Aref conductor
						// Channel 0

	ADCSRA = (1<<ADEN) |		// ADC- Enable 
				(1<<ADPS2) |	// ADPS = 64 -> 115kHz bei 7.372MHz
				(1<<ADPS1);
	ADCSRA |= (1<<ADSC);	// Mal ein Start auf den ADC


//	DIDR0 = 0xFF;	// Digitale Inputs am Eingangsport abgeschaltet
}


/*----------------------------------------------------------------------*/
//!	Get one sample from the adc
//! @param	channel => sampled channel
//! @return	value of the channel
/*----------------------------------------------------------------------*/
uint16_t sample_adc(uint8_t channel)
{
	uint16_t	value;

	// mask to vaild values
	channel &= 0x07;

	// select channel
	ADMUX &= 0xF0;
	ADMUX |= channel;

	ADCSRA |= (1<<ADSC);        // do single conversion
	while(!(ADCSRA & 0x10));    // wait for conversion done, ADIF flag active
        
	value = ADC;

	return value;
}

/*----------------------------------------------------------------------*/
//!	Get the meanvalue of 10 samples
//! @param	channel => sampled channel
//! @return	meanvalue of the channel
/*----------------------------------------------------------------------*/
uint16_t meansample_adc(uint8_t channel)
{
	uint8_t 	i;
	uint32_t	sum = 0;
	
	for( i = 0; i < SAMPLECOUNTER; i++)
	{
		sum += sample_adc(channel);
	}

	sum /= i;

	return ((uint16_t)sum);
}
