// lcd.h
/*----------------------------------------------------------------------*/
/*! \file 
/*----------------------------------------------------------------------*/
/*
  	<h3> lcd.h </h3>
  	Version	1.0<br>
  	Revision	$Revision: 1.4 $<br>
 	Copyright 	Thomas Wedemeyer, Email: avr@thomas-wedemeyer.de<br> 
  	Datum		$Date<br>

	<h1>IO-Interface for The Linksys WRT54 with Atmel AVR ATMega8</h1>  

	Controlfunctions for the HD44780-LCD in 4-Bit Mode
/*----------------------------------------------------------------------*/

#ifndef LCD_H
#define LCD_H


/*----------------------------------------------------------------------*/
//! Definitions
/*----------------------------------------------------------------------*/
#define LCD_SINGLELINE	0x00			//!< Single Line Display
#define LCD_MULTILINE	0x08			//!< Multiline Display
#define LCD_CURSORON	0x02			//!< Cursor on
#define LCD_CURSOROFF	0x00			//!< Cursor off
#define LCD_BLINKINGON	0x01			//!< Blinking on
#define LCD_BLINKINGOFF	0x00			//!< Blinking off

/*----------------------------------------------------------------------*/
//! LCD-Configuration
/*----------------------------------------------------------------------*/
#define LCD_LINEMD			LCD_MULTILINE	//!< Selected Mode!
#define LCD_CURSOR			LCD_CURSOROFF	//!< Cursor Mode
#define LCD_BLINKING		LCD_BLINKINGOFF	//!< Blinking 
#define	LCD_CHAR_PER_LINE	16				//!< Display Size
#define LCD_LINES			4				//!< Nr of Lines
#define LCD_ROW0_BASE		0x00			//!< Base of Row0 in DD-Ram
#define LCD_ROW1_BASE		0x40			//!< Base of Row1 in DD-Ram


/*----------------------------------------------------------------------*/
//! @brief Write a byte to the lcd
/*----------------------------------------------------------------------*/
void write_lcd(uint8_t reg, uint8_t data);


/*----------------------------------------------------------------------*/
//! @brief Init of the lcd in 4-Bit Mode
/*----------------------------------------------------------------------*/
void lcd_init();

/*----------------------------------------------------------------------*/
//! @brief Outputs a String at a defined position
//! @param	x	x-Pos in display row
//! @param	y	row-nr.
//! @param	*string	Pointer to String
/*----------------------------------------------------------------------*/
void print_lcd(int8_t x, int8_t y, uint8_t *string);


/*------------------------------------------------------------------------
	Lschen des Displays
/*----------------------------------------------------------------------*/
void clr_lcd();



#endif
