// uart.h
/*----------------------------------------------------------------------*/
/*! \file 
--------------------------------------------------------------------------

  	<h3> uart.h </h3>
  	Version	1.0<br>
  	Revision	$Revision: 1.4 $<br>
 	Copyright 	Thomas Wedemeyer, Email: avr@thomas-wedemeyer.de<br> 
  	Datum		$Date<br>

	<h1>IO-Interface for The Linksys WRT54 with Atmel AVR ATMega8</h1>  

	Simple RS232-functions with a buffered receiver 
/*----------------------------------------------------------------------*/

#ifndef UART_H
#define UART_H

#include <avr/pgmspace.h>
/*----------------------------------------------------------------------*/
//!	Configuration UART
/*----------------------------------------------------------------------*/
#define RXBUFFERSIZE	64					// Size of Receiverbuffer
#define RXBUFFERMAX		(RXBUFFERSIZE-1)

#define USART_BAUD_RATE 	115200 
#define USART_BAUD_SELECT 	(F_CPU/(USART_BAUD_RATE*16L)-1)

#define INIT_FOR_PRINTF

/*----------------------------------------------------------------------*/
//!	Structur for the buffered receiver
/*----------------------------------------------------------------------*/
struct uart_receive {
	volatile uint8_t 		index;
	volatile uint8_t 		buffer[RXBUFFERSIZE];
	volatile uint8_t 		new_data;
};


/*----------------------------------------------------------------------*/
//! Function: Sending a single Character
//! @param	c	Character to send
//! @return	Always zero
/*----------------------------------------------------------------------*/
int _writeChar (char c);


/*----------------------------------------------------------------------*/
//! Send a string via the uart
//! @param	string	Pointer to the string
//! return 	always zero
/*----------------------------------------------------------------------*/
int8_t _writeString (uint8_t *string); 

/*----------------------------------------------------------------------*/
//! Send a constant string (from flash) via the uart
//! @param	string	Pointer to the string
//! return 	always zero
/*----------------------------------------------------------------------*/
int8_t _writePString (PGM_P string);
 
/*----------------------------------------------------------------------*/
//! Init of the UART
/*----------------------------------------------------------------------*/
void init_uart();


/*----------------------------------------------------------------------*/
//! Check New-Data-Flag
//! @return 0 = No new Data, 1 = New Data 
/*----------------------------------------------------------------------*/
uint8_t uart_newdata();

 
/*----------------------------------------------------------------------*/
//! GetPointer to the RX-Buffer
//! @return pointer to the buffer 
/*----------------------------------------------------------------------*/
uint8_t *uart_getrxptr();

/*----------------------------------------------------------------------*/
//! Clear RX-Buffer
/*----------------------------------------------------------------------*/
void uart_clearbuf();

/*----------------------------------------------------------------------*/
//! Copy received data to a new buffer
//! @param	ptr Pointer to new_buffer 
//! @return Number of bytes copied  
/*----------------------------------------------------------------------*/
uint8_t uart_get(uint8_t *ptr);


#endif

